@@ -1,6 +1,5 @@
 from .app import app
-from .pack import *
-
+from .pack import *  # noqa: F401, F403
 
 if __name__ == "__main__":
     app()
